/*
 * Example of use for the API javax.swing.text.html.parser to parse
 * the HTML file in order to collect ancors
 * Author: M. Sighireanu
 */
import java.io.*;
import javax.swing.text.html.*;
import java.sql.*;
import java.io.*;
import javax.swing.text.html.*;
import javax.swing.text.html.parser.*;
import javax.swing.text.*;
import java.util.*;


////////////////////// Class extending the Parser for HTML to do a specific treatment of ancors.

public class CrawlerCallbackHandler extends HTMLEditorKit.ParserCallback {
    boolean isInsideLink = false;
	TabURI tab=null;
	TabPageAPaser vecteurLiens=null;
	TabLiensVisites PageDejaVisitee=null;
	AdresseURI adr;
	String keyword;
	String cheminRacine;
	boolean optionImage=false;
	boolean optionMail=false;




	public 	CrawlerCallbackHandler (TabURI tab, TabPageAPaser vecteurLiens, TabLiensVisites PageDejaVisitee, String cheminRacine, boolean optionImage, boolean optionMail) throws Exception { 
		
		this.tab = tab;tab=new TabURI();
		this.vecteurLiens = vecteurLiens;
		this.PageDejaVisitee = PageDejaVisitee;
		this.cheminRacine = cheminRacine;
		this.optionImage = optionImage;
		this.optionMail = optionMail;
	}




    public void handleStartTag(HTML.Tag tag, 
                               javax.swing.text.MutableAttributeSet set, 
                               int i) {

        if (tag.equals(HTML.Tag.A)) {
            isInsideLink = true;
            Object link = set.getAttribute(HTML.Attribute.HREF);
            if (link != null){

		String lien=link.toString();

		//Lien interne, on ne fait rien
		if((lien.toLowerCase().indexOf("#")==0))
			System.out.println("Lien interne: " + link.toString());
	
		//Lien mail, on l'enregistre si l'option mail est "true"
		if((lien.toLowerCase().indexOf("mailto:")>=0) || (lien.toLowerCase().indexOf("@")>=0)){
			//Si l'option --mail est demande, on enregiste les mails trouves
			if(optionMail){
				System.out.println("Lien mailto: " + link.toString());
				adr = new AdresseURI(link.toString(),"mail", null);
				tab.inser(adr);
			}
		}
		//Lien page
		else{

			//On transforme le lien en chemin absolue.
			lien=VerifieTransformeChemin(link.toString());

			//On verifie d'abord que la page n'a pas deja ete visitee.
			//Si tel est le cas, on l'enregistre sur les 3 tableaux.
			if(!PageDejaVisitee.verifierDejaVisitee(lien)) {
				adr = new AdresseURI(lien,"lien", null);
				tab.inser(adr);
				vecteurLiens.inser(lien);
				PageDejaVisitee.inser(lien);	
			}

		}
	    
	    }//fin if

        }//fin if


    }//fin handleStartTag





    public void handleEndTag(HTML.Tag tag, int i) {
        //System.out.println("end: " + tag.toString());
        if (tag.toString().compareToIgnoreCase("a") == 0) {
            isInsideLink = false;
        }

    }











    public void handleSimpleTag(HTML.Tag tag, 
                                javax.swing.text.MutableAttributeSet set, 
                                int i) {

	String image; // le nom de l'image
	String commentaireImage; // les mots clefs de l'image
	
	//On rencontre une image sur la page parser
        if ((tag.equals(HTML.Tag.IMG)) && (optionImage)){

            Object src = set.getAttribute(HTML.Attribute.SRC);
            Object alt = set.getAttribute(HTML.Attribute.ALT);

	    if (alt != null) { // L'image possede un commentaire
		if(src != null) {
			//On verifie que le lien est absolue
			image=VerifieTransformeChemin(src.toString());
			commentaireImage =  alt.toString().toLowerCase();
	        	adr = new AdresseURI(image,"image",commentaireImage);
		}
		tab.inser(adr);
	    }

	    else if(src != null) { // L'image ne possede pas de commentaire
		//On verifie que le lien est absolue
		image=VerifieTransformeChemin(src.toString());
		
		//Nous allons entrer le nom du fichier de l'image en dans le champs info de adr
		int position = image.lastIndexOf('/');
		commentaireImage = image.substring(position+1,image.length());
	        adr = new AdresseURI(image,"image",commentaireImage);
		tab.inser(adr);
	    }
	
	
        }

    }




    public void handleText(char[] aChar, int i) {


        if (isInsideLink){
		adr.setAdresseInfo(new String(aChar));
            	System.out.println(aChar);

	}

    }






/*
    public void handleText(char[] aChar, int i) {
        if (isInsideLink)
            System.out.println(aChar);
    }

*/



/////////////////////////////////////////////////////////////////////////////////
//
//		Fonctions pour la manipulation des chemins relatifs
//
////////////////////////////////////////////////////////////////////////////////


	//Methode qui verifie si le lien trouve est absolue ou relatif
	//Si il est relatif, on le transforme en absolue
	public String VerifieTransformeChemin(String chemin) {

		//Verifie si il s'agit bien d'un chemin absolue
		if(chemin.startsWith("http://")){
			return chemin;
		}
		else {

			//Lien commencant par '/'
			if(chemin.startsWith("/")) {
				String tampon;
				tampon  = cheminRacine;
				chemin = tampon + chemin.substring(1);
				return chemin;
			}
			else if(chemin.startsWith("./")) {
				String tampon;
				tampon  = cheminRacine;
				chemin = tampon + chemin.substring(2);
				return chemin;
			}
			else if(chemin.startsWith("../")) {
				//A faire
				return chemin;
			}
			//Lien contenant uniquement un nom de fichier
			else {
				chemin = cheminRacine + chemin;
				return chemin;
			}
		}			

	}




}

